Index: other-projects/trunk/gs3-webservices-democlient/src/GS3Fedora/org/greenstone/fedora/services/FedoraGS3Connection.java
===================================================================
--- other-projects/trunk/gs3-webservices-democlient/src/GS3Fedora/org/greenstone/fedora/services/FedoraGS3Connection.java	(revision 15732)
+++ other-projects/trunk/gs3-webservices-democlient/src/GS3Fedora/org/greenstone/fedora/services/FedoraGS3Connection.java	(revision 15733)
@@ -70,10 +70,5 @@
 	private static final Logger LOG = Logger.getLogger(
 			FedoraGS3Connection.class.getName());
-	
-	/** The last part of the gSearchWSDL URL. The first part is
-	 * the same as the fedora server's base url. */
-	protected static final String gSearchWSDLSuffix
-		= "gsearch/services/FgsOperations?wsdl";
-	
+		
 	/** Complete list of services that are supported our FedoraGS3 would  
 	 * support if everything goes well. If a connection to FedoraGSearch
@@ -109,5 +104,9 @@
 	 * concatenated to "gsearch/services/FgsOperations?wsdl" */
 	protected String gSearchWSDLURL;
-	
+	    
+	/** The last part of the gSearchWSDL URL. The first part is
+	 * the same as the fedora server's base url. */
+        protected String gSearchWSDLSuffix;
+		    
 	/** The name of the index that FedoraGSearch will index the GS3
 	 * documents into. If no name is specified in the properties file,
@@ -179,9 +178,10 @@
 	 * properties loaded from a propertiesFile. This method is overridden  
 	 * here in order to instantiate the gSearchConnection based on the  
-	 * - gSearchWSDLURL (If one was not provided in the properties file,  
-	 * gSearchWSDLURL defaults to something of the form
-	 * "http://localhost:8080/fedoragsearch/services/FgsOperations?wsdl"
-	 * where http://localhost:8080/fedora is the baseURL of fedora and
-	 * "gsearch/services/FgsOperations?wsdl" is the default gSearchWSDLSuffix.)
+	 * - gSearchWSDLSuffix that will be appended to the fedora base url.
+	 * (If one was not provided in the properties file, gSearchWSDLURL defaults 
+	 * to something of the form
+	 * "http://&lt;fedorahost:port&gt;/fedoragsearch/services/FgsOperations?wsdl"
+	 * which is the baseURL of fedora concatenated to the default gSearchWSDLSuffix,
+	 * "gsearch/services/FgsOperations?wsdl".
 	 * - name of the index into which the GS3 documents have been indexed 
 	 * and which FedoraGenericSearch should use to perform searches. If none is
@@ -189,7 +189,7 @@
 	 * @param properties is the Properties Map loaded from a properties file
 	 * (if there was any) which specifies such things as host and port of the
 	 * FedoraServer, but can also specify the property "gsearch.wsdlURL".
 	 * At the end of this method, properties' "gsearch.wsdlURL" will be set
 	 * to whatever the final value of this.gSearchWSDLURL is, and 
 	 * "gsearch.indexName" will be set to to whatever the final value of
 	 * this.gSearchIndexName is. 
@@ -201,12 +201,13 @@
 	{
 		super.setInitialisationProperties(properties);
-		// gsearchWSDL URL, if not specified, defaults to something of the form:
-		// "http://localhost:8080/fedoragsearch/services/FgsOperations?wsdl"
-		// where http://localhost:8080/fedora is the baseURL of fedora
-		this.gSearchWSDLURL = properties.getProperty(
-				"gsearch.wsdlURL", this.baseURL+gSearchWSDLSuffix);
+		// gsearchWSDL URL suffix, if not specified, defaults to 
+		// "fedoragsearch/services/FgsOperations?wsdl" which is 
+		// concatenated to the baseURL of fedora to give the gsearchWSDLURL.
+		this.gSearchWSDLSuffix = properties.getProperty(
+			"gsearch.wsdlURL.suffix", "gsearch/services/FgsOperations?wsdl");
+		this.gSearchWSDLURL = this.baseURL + this.gSearchWSDLSuffix;
 		// Set the property to whatever this.gSearchWSDLURL is now,
 		// so that it will be written out to the properties file again
-		properties.setProperty("gsearch.wsdlURL", this.gSearchWSDLURL);
+		properties.setProperty("gsearch.wsdlURL.suffix", this.gSearchWSDLSuffix);
 		
 		// Similarly for the name of the index FedoraGenericSearch should use
@@ -189,7 +189,7 @@
 	 * @param properties is the Properties Map loaded from a properties file
 	 * (if there was any) which specifies such things as host and port of the
-	 * FedoraServer, but can also specify the property "gsearch.wsdlURL".
-	 * At the end of this method, properties' "gsearch.wsdlURL" will be set
-	 * to whatever the final value of this.gSearchWSDLURL is, and 
+	 * FedoraServer, but can also specify the property "gsearch.wsdlURL.suffix".
+	 * At the end of this method, properties' "gsearch.wsdlURL.suffix" will be set
+	 * to whatever the final value of this.gSearchWSDLURL' suffix is, and 
 	 * "gsearch.indexName" will be set to to whatever the final value of
 	 * this.gSearchIndexName is. 
